@@ -1,7 +1,8 @@
 """Low-level, pure Python DBus protocol wrapper.
 """
+from .auth import AuthenticationError
 from .low_level import Message, Parser
 from .bus import find_session_bus, find_system_bus
 from .wrappers import *
 
-__version__ = '0.3.1'
+__version__ = '0.4'
